@@ -4,6 +4,7 @@ import json
 import asyncio
 import websocket 
 import datetime
+import time
 from .error import InputError,InvalidAuthorizationError
 
 class API(object):
@@ -59,7 +60,11 @@ class API(object):
         link = self.domain + 'OrderOpen'
         
         # print(self.token)
-        response = requests.post(link, data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
+        try:
+            response = requests.post(link, data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
+        except:
+            time.sleep(1)
+            response = requests.post(link, data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
         return response.json()
 
     def close_order(self, ticket, lots = None, price = None):
@@ -80,7 +85,11 @@ class API(object):
         else:
             params = {"ticket":ticket,"lots":lots,"price":price}
         link = self.domain + 'OrderClose'
-        response = requests.post(link,data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
+        try:
+            response = requests.post(link,data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
+        except:
+            time.sleep(1)
+            response = requests.post(link,data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
         return response.json()
 
     def trades_history_by_datetime(self, start_time, end_time):
